@@ -69,8 +69,9 @@ and solutions provided by Scribe and Scribble to avoid these problems.
  Standard Scribe syntax doesn't provide a mean
  to include a closing bracket in bracketed text.
 
-* So as to prevent difficult to track syntax errors resulting from typos,
- Standard Scribe syntax forbids to include an opening bracket in the text.
+* Conversely, so as to prevent difficult to track syntax errors
+ resulting from typos, Standard Scribe syntax forbids
+ to include an opening bracket in the text.
 
 * As an extension to Scribe syntax,
  you can include any character in the text,
@@ -227,10 +228,10 @@ in your macros so as to customize the behaviour of preprocessing"
 into preprocessing forms")
 
 (defun scribble-preprocess (s)
-  (typecase *scribble-preprocess*
+  (etypecase *scribble-preprocess*
     (null s)
-    ((or symbol function) (funcall *scribble-preprocess* s))
-    (t `(pp ,s))))
+    ((eql t) `(pp ,s))
+    ((or symbol function) (funcall *scribble-preprocess* s))))
 
 ;-----------------------------------------------------------------------------
 ;;; Customizing components combination
